@@ -1,7 +1,7 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
-from decimal import Decimal
 import operator
+from decimal import Decimal
 
 from trytond.i18n import gettext
 from trytond.pool import Pool, PoolMeta
@@ -70,8 +70,7 @@ class InvoiceLine(metaclass=PoolMeta):
 
         accounting_date = (self.invoice.accounting_date
             or self.invoice.invoice_date)
-        period_id = Period.find(self.invoice.company.id, date=accounting_date)
-        period = Period(period_id)
+        period = Period.find(self.invoice.company, date=accounting_date)
         if period.fiscalyear.account_stock_method != 'anglo_saxon':
             return result
 
