@@ -1,12 +1,10 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
-from trytond import backend
 from trytond.model import fields
-from trytond.pyson import Eval
-from trytond.pool import PoolMeta, Pool
-
 from trytond.modules.account_product.product import (
     account_used, template_property)
+from trytond.pool import Pool, PoolMeta
+from trytond.pyson import Eval
 
 
 class Category(metaclass=PoolMeta):
@@ -21,8 +19,7 @@ class Category(metaclass=PoolMeta):
                 'invisible': (~Eval('context', {}, ).get('company')
                     | Eval('account_parent')
                     | ~Eval('accounting', False)),
-                },
-            depends=['account_parent', 'accounting']))
+                }))
 
     @classmethod
     def multivalue_model(cls, field):
@@ -51,28 +48,7 @@ class CategoryAccount(metaclass=PoolMeta):
             ('closed', '!=', True),
             ('type.expense', '=', True),
             ('company', '=', Eval('company', -1)),
-            ],
-        depends=['company'])
-
-    @classmethod
-    def __register__(cls, module_name):
-        exist = backend.TableHandler.table_exist(cls._table)
-        if exist:
-            table = cls.__table_handler__(module_name)
-            exist &= table.column_exist('account_cogs')
-
-        super(CategoryAccount, cls).__register__(module_name)
-
-        if not exist:
-            # Re-migration
-            cls._migrate_property([], [], [])
-
-    @classmethod
-    def _migrate_property(cls, field_names, value_names, fields):
-        field_names.append('account_cogs')
-        value_names.append('account_cogs')
-        super(CategoryAccount, cls)._migrate_property(
-            field_names, value_names, fields)
+            ])
 
     @classmethod
     def get_account_stock_type_statements(cls):
